@@ -1293,5 +1293,5 @@ main(int argc,char **argv)
   
   nco_exit_gracefully();
   return EXIT_SUCCESS;
-} /* end main() */
+} /* !main() */
 
