@@ -22,7 +22,7 @@
 /* 3rd party vendors */
 #include <netcdf.h> /* netCDF definitions and C library */
 #ifdef NC_HAVE_META_H
-# include <netcdf_meta.h> /* NC_VERSION_..., NC_HAVE_RENAME_GRP */
+# include <netcdf_meta.h> /* NC_VERSION_..., NC_HAS_QUANTIZE, NC_HAS_ZSTD */
 #endif /* !NC_HAVE_META_H */
 
 /* Personal headers */
@@ -244,12 +244,12 @@ extern "C" {
 #endif /* NCO_MSS_VAL_SNG */
 
   /* Prototype global functions before defining them in next block */
+  char *nco_cmp_glb_get(void); /* [sng] Global compression specification */
   char *nco_mss_val_sng_get(void); /* [sng] Missing value attribute name */
   char *nco_mta_dlm_get(void); /* [sng] Multi-argument delimiter */
   char *nco_not_mss_val_sng_get(void); /* [sng] Not missing value attribute name */
   char *nco_prg_nm_get(void);
   int nco_prg_id_get(void);
-  int nco_flt_glb_get(void);
   unsigned short nco_baa_cnv_get(void);
   unsigned short nco_bnr_cnv_get(void);
   unsigned short nco_dbg_lvl_get(void);
@@ -257,6 +257,7 @@ extern "C" {
   unsigned short nco_mrd_cnv_get(void);
   unsigned short nco_rth_cnv_get(void);
   unsigned short nco_upk_cnv_get(void);
+  void nco_cmp_glb_set(char *nco_cmp_glb_arg); /* [sng] Global compression specification */
   void nco_fmt_xtn_set(unsigned short nco_fmt_xtn_arg);
   void nco_mta_dlm_set(char *nco_mta_dlm_arg);
 
@@ -275,7 +276,7 @@ extern "C" {
     return nco_mta_dlm;} /* [sng] Multi-argument delimiter */
   void nco_mta_dlm_set(char *nco_mta_dlm_arg){nco_mta_dlm=nco_mta_dlm_arg;} /* [sng] Multi-argument delimiter */
   
-  unsigned short nco_baa_cnv=4; /* [enm] Bit-Adjustment Algorithm defaults to Granular Bit Grooming (after 20211003) */
+  unsigned short nco_baa_cnv=4; /* [enm] Bit-Adjustment Algorithm defaults to Granular BitRound (after 20211003) */
   unsigned short nco_baa_cnv_get(void){return nco_baa_cnv;} /* [enm] Bit-Adjustment Algorithm */
 
   unsigned short nco_bnr_cnv=0; /* [enm] Binary byte-ordering convention to produce (native or byte-swapped) */
@@ -284,8 +285,9 @@ extern "C" {
   unsigned short nco_dbg_lvl=0; /* [enm] Debugging level */
   unsigned short nco_dbg_lvl_get(void){return nco_dbg_lvl;} /* [enm] Debugging level */
 
-  int nco_flt_glb=0; /* [enm] Filter enum */
-  int nco_flt_glb_get(void){return nco_flt_glb;} /* [enm] Filter enum */
+  char *nco_cmp_sng_glb=NULL; /* [sng] Global compression specification */
+  char *nco_cmp_glb_get(void){return nco_cmp_sng_glb;} /* [sng] Global compression specification */
+  void nco_cmp_glb_set(char *nco_cmp_glb_arg){nco_cmp_sng_glb=nco_cmp_glb_arg;} /* [sng] Global compression specification */
 
   unsigned short nco_fmt_xtn=0; /* [enm] Extended file format */
   unsigned short nco_fmt_xtn_get(void){return nco_fmt_xtn;} /* [enm] Extended file format */
@@ -361,10 +363,10 @@ extern "C" {
 # define NCO_VERSION_MAJOR 5
 #endif /* !NCO_VERSION_MAJOR */
 #ifndef NCO_VERSION_MINOR
-# define NCO_VERSION_MINOR 0
+# define NCO_VERSION_MINOR 1
 #endif /* !NCO_VERSION_MINOR */
 #ifndef NCO_VERSION_PATCH
-# define NCO_VERSION_PATCH 6
+# define NCO_VERSION_PATCH 3
 #endif /* !NCO_VERSION_PATCH */
 #ifndef NCO_VERSION_NOTE
 # define NCO_VERSION_NOTE "" /* Blank for final versions, non-blank (e.g., "-beta37") for pre-release versions */
@@ -374,7 +376,7 @@ extern "C" {
 # define NCO_LIB_VERSION ( NCO_VERSION_MAJOR * 100 + NCO_VERSION_MINOR * 10 + NCO_VERSION_PATCH )
 #endif /* !NCO_LIB_VERSION */
 #ifndef NCO_VERSION
-# define NCO_VERSION "5.0.6"
+# define NCO_VERSION "5.1.3"
 #endif /* !NCO_VERSION */
 
 /* Compatibility tokens new to netCDF4 netcdf.h: */
@@ -414,6 +416,18 @@ extern "C" {
 #endif
 #ifndef NC_CONTIGUOUS
 # define NC_CONTIGUOUS (1)
+#endif
+  /* Added ~2019 */
+#ifndef NC_COMPACT
+# define NC_COMPACT (2)
+#endif
+  /* Added 202206 netCDF 4.9.0 */
+#ifndef NC_UNKNOWN_STORAGE
+# define NC_UNKNOWN_STORAGE (3)
+#endif
+  /* Added 202206 netCDF 4.9.0 */
+#ifndef NC_VIRTUAL
+# define NC_VIRTUAL (4)
 #endif
 #ifndef NC_NOCHECKSUM
 # define NC_NOCHECKSUM 0
@@ -517,6 +531,9 @@ extern "C" {
 #endif
 #ifndef NC_FORMATX_DAP4
 # define NC_FORMATX_DAP4    (6)
+#endif
+#ifndef NC_FORMATX_NCZARR
+# define NC_FORMATX_NCZARR  (10)
 #endif
 
   /* Three compatibility tokens from pnetcdf.h introduced to NCO 20140604 
@@ -547,6 +564,10 @@ extern "C" {
 #endif
 #ifndef NC_EDAPSVC
 # define NC_EDAPSVC (-70)      /**< DAP server error */
+#endif
+  /* Backwards-compatibility error codes implemented in 202207 to diagnose problems with NCZarr */
+#ifndef NC_ENCZARR
+# define NC_ENCZARR (-137)    /**< Error at NCZarr layer. */
 #endif
 
   /* Backwards-compatibility error codes implemented in 202004 to workaround netCDF 4.7.4 backwards incompatibility with nc_inq_var_filter()
@@ -723,6 +744,8 @@ extern "C" {
     nco_fmt_xtn_pnetcdf=NC_FORMAT_PNETCDF, /* 4 PnetCDF */
     nco_fmt_xtn_dap2=NC_FORMAT_DAP2, /* 5 DAP2 */
     nco_fmt_xtn_dap4=NC_FORMAT_DAP4, /* 6 DAP4 */
+    /* 20220713: Tokens defined as of netCDF 4.8.0 */
+    nco_fmt_xtn_nczarr=NC_FORMATX_NCZARR, /* 10 NCZARR */
   }; /* end nco_fmt_xtn */
 
   enum nco_mrd_cnv{ /* [enm] Multiple Record Dimension convention: for ncecat and ncpdq */
@@ -738,12 +761,12 @@ extern "C" {
   }; /* end nco_rth_cnv */
 
   enum nco_baa_cnv{ /* [enm] Bit-Adjustment Algorithm to use */
-    nco_baa_bgr, /* 0 BitGroom (option since 201502XX, default 201502XX--20200717) */
+    nco_baa_btg, /* 0 BitGroom (option since 201502XX, default 201502XX--20200717) */
     nco_baa_shv, /* 1 BitShave (option since 20160117) */
     nco_baa_set, /* 2 BitSet (option since 20160117) */
     nco_baa_dgr, /* 3 DigitRound (DCG19 option since 20210928, default 20210928--20211003) */
     nco_baa_gbr, /* 4 Granular BitRound (option since 20211003, default 20211003--present) */
-    nco_baa_bgr_btr, /* 5 BitGroomRound (option since 20200717, default 20200717--20210928) */
+    nco_baa_bgr, /* 5 BitGroomRound (option since 20200717, default 20200717--20210928) */
     nco_baa_sh2, /* 6 BitHalf-shave (option since 20200715) */
     nco_baa_brt, /* 7 BruteForce (option since 20210428) */
     nco_baa_btr, /* 8 BitRound (option since 20211215 */
@@ -1151,7 +1174,8 @@ typedef enum nco_xtr_typ_enm
     char *fl_out; /* [sng] File containing regridded fields */
     char *fl_out_tmp; /* [sng] Temporary file containing regridded fields */
     char *fl_map; /* [sng] File containing mapping weights from source to destination grid */
-    char *fl_vrt; /* [sng] File containing vertical coordinate grid */
+    char *fl_vrt_in; /* [sng] File containing input vertical coordinate grid */
+    char *fl_vrt_out; /* [sng] File containing output vertical coordinate grid */
     char *fl_msh;  /* [sng] File that contains SCRIP formatted overlap mesh */
     char *var_nm; /* [sng] Variable for special regridding treatment */
     // Grid names specifiable with key-value syntax
@@ -1180,9 +1204,15 @@ typedef enum nco_xtr_typ_enm
     char *lon_nm_out; /* [sng] Name of output dimension for longitude */
     char *lon_vrt_nm; /* [sng] Name of non-rectangular boundary variable for longitude */
     char *msk_nm; /* [sng] Name of variable containing destination mask */
-    char *plev_nm_in; /* [sng] Name of variable to recognize as vertical coordinate for pure pressure grids */
+    char *plev_nm_in; /* [sng] Name of input variable to recognize as vertical coordinate for pure pressure grids */
+    char *plev_nm_out; /* [sng] Name of variable to output as vertical coordinate for pure pressure grids */
+    char *plev_nm_tpl; /* [sng] Name of template variable to recognize as vertical coordinate for pure pressure grids */
+    char *ps_nm_in; /* [sng] Name of input variable to recognize as surface pressure for hybrid/sigma pressure grids */
+    char *ps_nm_out; /* [sng] Name of variable to output as surface pressure for hybrid/sigma pressure grids */
+    char *ps_nm_tpl; /* [sng] Name of template variable to recognize as surface pressure for hybrid/sigma pressure grids */
     char *sgs_frc_nm; /* [sng] Name of variable containing sub-gridscale fraction */
     char *sgs_msk_nm; /* [sng] Name of variable containing sub-gridscale mask */
+    char *vrt_in; /* [sng] Name of file containing vertical grid coefficients for input file */
     char *vrt_nm; /* [sng] Name of dimension to employ for vertices */
     // User-specified grid properties
     char *fl_grd; /* [sng] Name of SCRIP grid file to create */
