@@ -140,7 +140,7 @@ nco_cnk_csh_ini /* [fnc] Initialize global chunk cache user-specified input */
 
   float pmp_fvr_frc; /* [frc] Pre-emption favor fraction */
 
-  int rcd=0; /* [enm] Return code  */
+  int rcd=0; /* [enm] Return code */
   
   size_t cnk_csh_byt_crr; /* I [B] Chunk cache size current setting */
   size_t nelemsp; /* [nbr] Chunk slots in raw data chunk cache hash table */
@@ -158,7 +158,7 @@ nco_cnk_csh_ini /* [fnc] Initialize global chunk cache user-specified input */
   } /* !dbg */
 
   return rcd;
-} /* end nco_cnk_csh_ini() */
+} /* !nco_cnk_csh_ini() */
 
 int /* [rcd] Return code */
 nco_cnk_ini /* [fnc] Initialize chunking from user-specified inputs */
@@ -210,7 +210,10 @@ nco_cnk_ini /* [fnc] Initialize chunking from user-specified inputs */
      Yellowstong /glade     131072 524288
      Yellowstong /tmp         4096 524288 <-- probably hardcoded default not actual blocksize reported */
 
-  /* Discover blocksize if possible */
+  /* Discover blocksize if possible
+     netCDF ID in_id points to input file, while fl_out to output file name (not ID)
+     Do not pass anything about the input file to nco_fl_blocksize()
+     We do need name (not ID) of output file in order to perform stat() on output directory */
   fl_sys_blk_sz=nco_fl_blocksize(fl_out);
 
   if(cnk_sz_byt > 0ULL){
@@ -263,7 +266,7 @@ nco_cnk_ini /* [fnc] Initialize chunking from user-specified inputs */
   if(cnk->cnk_plc == nco_cnk_plc_nco) cnk->cnk_plc=nco_cnk_plc_all;
 
   return rcd;
-} /* end nco_cnk_ini() */
+} /* !nco_cnk_ini() */
 
 cnk_dmn_sct ** /* O [sct] Structure list with user-specified per-dimension chunking information */
 nco_cnk_prs /* [fnc] Create chunking structures with name and chunksize elements */
@@ -906,6 +909,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   size_t cnk_min_byt; /* [B] Minimize size of variable to chunk */
   size_t cnk_sz_dfl; /* [nbr] Chunksize default */
   size_t cnk_sz_scl; /* [nbr] Chunk size scalar */
+  size_t flt_nbr; /* [nbr] Filter number */
   size_t typ_sz; /* [B] Bytes per value */
   size_t var_sz_byt; /* [B] Size of variable in output file */
 
@@ -994,6 +998,11 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   (void)nco_inq_var_deflate(grp_id_out,var_id_out,&shuffle,&deflate,(int *)NULL);
   if(deflate) is_cmp_var=True; 
 
+  /* 20220708 Compression filters can be, like, anything nowadays
+     New is_cmp_var criterion will be true whenever any Filter has been applied */
+  (void)nco_inq_var_filter_ids(grp_id_out,var_id_out,&flt_nbr,NULL);
+  if(flt_nbr > 0) is_cmp_var=True;
+  
   /* Is variable check-summed? */
   (void)nco_inq_var_fletcher32(grp_id_out,var_id_out,&chk_typ);
   if(chk_typ != NC_NOCHECKSUM) is_chk_var=True;
@@ -1002,7 +1011,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   if(is_rec_var || is_chk_var || is_cmp_var) must_be_chunked=True; else must_be_chunked=False;
 
   /* Is variable currently chunked? */
-  if( var_id_in>=0 &&  (nco_fmt_xtn_get() != nco_fmt_xtn_hdf4 || (NC_LIB_VERSION >= 433 && NC_LIB_VERSION != 474)))
+  if(var_id_in>=0 && (nco_fmt_xtn_get() != nco_fmt_xtn_hdf4 || (NC_LIB_VERSION >= 433 && NC_LIB_VERSION != 474)))
     is_chunked=nco_cnk_dsk_inq(grp_id_in,var_id_in);
   else
     is_chunked=False;
@@ -1047,6 +1056,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 	  if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s turning-off shuffle filter before unchunking variable %s\n",nco_prg_nm_get(),fnc_nm,var_nm);
 	  shuffle=NC_NOSHUFFLE;
 	  deflate=0;
+	  /* 20220503: Replace with more generic nco_flt_old() wrapper to turn-off all codecs? */
 	  (void)nco_def_var_deflate(grp_id_out,var_id_out,shuffle,deflate,(int)0);
 	} /* !shuffle */
 	/* Redundant since default netCDF srg_typ = NC_CONTIGUOUS for variables that need not be chunked */
@@ -1277,7 +1287,11 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     /* First-guess estimate of chunk size */
     size_t cnk_sz_prd=1L;
     for(dmn_idx=0;dmn_idx<=dmn_nbr-1;dmn_idx++) cnk_sz_prd*=cnk_sz_rgn[dmn_idx];
-    assert(cnk_sz_prd*typ_sz <= cnk_sz_byt);
+    /* 20221118: This assert() was present in the code until today
+       Benchmark SCREAM data fails this assert() yet successfully regrids if it is removed
+       This is because the original guesstimates, cnk_sz_rgn, can violate the assert() though
+       the final chunk sizes (that netCDF eventually sees) do not */
+    //assert(cnk_sz_prd*typ_sz <= cnk_sz_byt);
 
     /* prm_idx = prm_cff[0]*2^0 + prm_cff[1]*2^1 + prm_cff[2]*2^2 + ... + prm_cff[dmn_nbr-1]*2^(dmn_nbr-1) */
     two_pwr_idx[0]=1L;
@@ -1402,7 +1416,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     }else{
       /* Override was not performed due to policy, so continue to next dimension */
       continue;
-    } /* endif */
+    } /* !cnk_plc */
 
     /* Sanity checks for dimensions that were over-ridden by user-specified chunksizes */
 
@@ -1415,12 +1429,12 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 	   cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
 	  if(FIRST_WARNING) (void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize %lu which exceeds current output file record dimension size = %lu. May fail if output file is not concatenated from multiple inputs. Will only print this WARNING once.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
 	  FIRST_WARNING=False;
-	} /* endif too big */
+	} /* !dmn_cmn, too big */
       }else{ /* !NON_HYP_DMN */
 	if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].dmn_cnt){
 	  if(FIRST_WARNING) (void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize = %lu which exceeds user-specified record dimension input hyperslab size = %lu. May fail if output file is not concatenated from multiple inputs. Will only print this WARNING once.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].dmn_cnt);
 	  FIRST_WARNING=False;
-	} /* endif too big */
+	} /* !cnk_sz, too big */
       } /* !NON_HYP_DMN */
     }else{ /* !rcd_dmn_id */
       if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
@@ -1428,10 +1442,10 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 	(void)fprintf(stderr,"%s: WARNING %s trimming user-specified fixed dimension %s chunksize from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
 	/* Trim else out-of-bounds sizes will fail in HDF library in nc_enddef() */
 	cnk_sz[dmn_idx]=(size_t)dmn_cmn[dmn_idx].sz;
-      } /* endif */
+      } /* !cnk_sz */
     } /* !rcd_dmn_id */
 
-  } /* end loop over dmn_idx */
+  } /* !dmn_idx */
 
   /* Final Safety Check */
  cnk_sft_chk: /* end goto */
@@ -1452,20 +1466,20 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
         if(nco_dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stderr,"%s: INFO %s final check trimming chunksize of \"%s\" dimension from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_sz[dmn_idx],(unsigned long)dmn_cmn[dmn_idx].sz);
         /* Trim else out-of-bounds sizes will fail in HDF library in nc_enddef() */
         cnk_sz[dmn_idx]=(size_t)dmn_cmn[dmn_idx].sz;
-      } /* rcd_dmn_id */
-    } /* end if */
+      } /* !dmn_cmn.is_rec_dmn */
+    } /* !cnk_sz */
     /* 20170610: TODO nco1137 bug ncwa chunking fails with --rdd reported by Joy 20170605 because dmn_cmn[] contains zero for some dimensions */
     if(cnk_sz[dmn_idx] == 0L){
       if(nco_dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stderr,"%s: INFO %s final check manually overriding chunksize of \"%s\" dimension from 0L to 1L as workaround to TODO nco1137: bad interaction of chunking with --rdd\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm);
       cnk_sz[dmn_idx]=1L;
-    } /* end cnk_sz */
-  } /* end loop over dmn */
+    } /* !cnk_sz */
+  } /* !dmn_idx */
 
   if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev){
     /* Dimensions and chunksizes used by variable in output file */
     (void)fprintf(stdout,"idx dmn_nm\tdmn_sz\tcnk_sz:\n");
     for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++) (void)fprintf(stdout,"%2d %s \t%lu\t%lu\n",dmn_idx,dmn_cmn[dmn_idx].nm_fll,(unsigned long)dmn_cmn[dmn_idx].sz,(unsigned long)cnk_sz[dmn_idx]);
-  } /* endif dbg */
+  } /* !dbg */
 
   /* Set storage (chunked or contiguous) for this variable */
   (void)nco_def_var_chunking(grp_id_out,var_id_out,srg_typ,cnk_sz);
@@ -1474,4 +1488,4 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   if(cnk_sz) cnk_sz=(size_t *)nco_free(cnk_sz);
 
   return;
-} /* nco_cnk_sz_set_trv() */
+} /* !nco_cnk_sz_set_trv() */
