@@ -45,7 +45,11 @@ ptr_unn /* O [sct] Default missing value for type type */
 nco_mss_val_mk /* [fnc] Return default missing value for type type */
 (const nc_type type); /* I [enm] netCDF type of operand */
 
-nco_bool /* O [flg] One or both operands have missing value */
+val_unn /* O [sct] Default missing value for type type */
+nco_mss_val_dfl_get /* [fnc] Return default missing value for type type */
+(const nc_type type); /* I [enm] netCDF type of operand */
+
+  nco_bool /* O [flg] One or both operands have missing value */
 nco_mss_val_cnf /* [fnc] Change missing_value of var2 to missing_value of var1 */
 (var_sct * const var1, /* I [sct] Variable with template missing value to copy */
  var_sct * const var2); /* I/O [sct] Variable with missing value to fill-in/overwrite */
