@@ -28,6 +28,7 @@
 #include "nco.h" /* netCDF Operator (NCO) definitions */
 #include "nco_cnf_typ.h" /* Conform variable types nco_typ_ntg() */
 #include "nco_fl_utl.h" /* File manipulation */
+#include "nco_flt.h" /* Compression filters */
 #include "nco_mmr.h" /* Memory management */
 #include "nco_mss_val.h" /* Missing value utilities */
 #include "nco_omp.h" /* OpenMP utilities */
@@ -196,7 +197,8 @@ extern "C" {
    char * const rgr_hrz, /* I [sng] File containing horizontal coordinate grid */
    char * const rgr_map, /* I [sng] File containing mapping weights from source to destination grid */
    char * const rgr_var, /* I [sng] Variable for special regridding treatment */
-   char * const rgr_vrt, /* I [sng] File containing vertical coordinate grid */
+   char * const rgr_vrt_in, /* I [sng] File containing input vertical coordinate grid */
+   char * const rgr_vrt_out, /* I [sng] File containing output vertical coordinate grid */
    const double wgt_vld_thr, /* I [frc] Weight threshold for valid destination value */
    char **xtn_var, /* I [sng] Extensive variables */
    const int xtn_nbr); /* I [nbr] Number of extensive variables */
