@@ -205,10 +205,10 @@ nco_lbr_vrs_prn(void) /* [fnc] Print netCDF library version */
 const char * /* O [sng] Mnemonic that describes current NCO version */
 nco_nmn_get(void) /* [fnc] Return mnemonic that describes current NCO version */
 { 
-  /* Purpose: Return mnemonic describing current NCO version 
+  /* Purpose: Return mnemonic describing current NCO version
      20191221: ncremap/ncclimo print left quote and first word of this string, so one-word strings look best 
      20200117: fixed this limitation, multi-word versions work fine */
-  return "Rattlesnake";
+  return "Mauna Loa";
 } /* !nco_nmn_get() */
 
 void
